@@ -135,6 +135,10 @@ our $dispatch_map = {
     "PUT BUGREPORT" => \&_method_bugreport,
     "POST BUGREPORT" => \&_method_bugreport,
     "DELETE BUGREPORT" => \&_method_bugreport,
+    "GET CONFIGINFO" => \&_method_configinfo,
+    "PUT CONFIGINFO" => \&_method_configinfo,
+    "POST CONFIGINFO" => \&_method_configinfo,
+    "DELETE CONFIGINFO" => \&_method_configinfo,
     "GET COOKIEJAR" => \&_method_cookiejar,
     "PUT COOKIEJAR" => \&_method_cookiejar,
     "POST COOKIEJAR" => \&_method_cookiejar,
